import io

from backports import csv

COMMENT_CHAR = u'#'

DEFAULT_DELIMITER = u';'
DEFAULT_LINETERMINATOR = u'\n'


def strip_comments_and_empty_lines(lines):
    for line in lines:
        if not line.startswith(COMMENT_CHAR) and line.strip():
            yield line.strip()


def _read_csv(file_path, delimiter=DEFAULT_DELIMITER):
    return csv.reader(
        read_lines(file_path),
        delimiter=delimiter
    )


def _write_csv(
        file_path,
        data,
        delimiter=DEFAULT_DELIMITER,
        lineterminator=DEFAULT_LINETERMINATOR):
    with io.open(file_path, 'w', newline='', encoding='utf-8') as f:
        writer = csv.writer(
            f,
            delimiter=delimiter,
            lineterminator=lineterminator
        )
        writer.writerows(data)


def read_lines(file_path):
    with io.open(file_path, 'r', newline='', encoding='utf-8') as f:
        for line in strip_comments_and_empty_lines(f):
            yield line


read_map = _read_csv

write_map = _write_csv


def read_list(file_path):
    return [item[0] for item in _read_csv(file_path)]


def write_list(file_path, data):
    _write_csv(
        file_path,
        [[item] for item in data]
    )



from codecs import open
from os import path

from setuptools import find_packages, setup

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='listio',

    version='1.1.0',

    description='Read/write lists and maps (two dimensional lists) from/to'
    ' files.',
    long_description=long_description,

    url='https://github.com/jakubvalenta/listio',

    author='Jakub Valenta',
    author_email='jakub@jakubvalenta.cz',

    license='Apache Software License',

    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Topic :: Software Development',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],

    keywords='',

    packages=find_packages(),

    install_requires=[
        'backports.csv',
    ],
)
